@@ -1204,9 +1204,12 @@ char *getwd(path)
 	extern char *getcwd();
 	extern int errno;
 
-	if (getcwd(path, MAXPATHLEN) == (char *)NULL)
+	if (getcwd(path, MAXPATHLEN) == (char *)NULL) {
 		strncpy(path, strerror(errno), MAXPATHLEN);
-	path[MAXPATHLEN] = 0;
+		path[MAXPATHLEN] = 0;
+		return (0);
+	}
+	return (path);
 }
 #endif
 
@@ -1427,7 +1430,6 @@ send_file_list(whichfiles)
 	struct dirent *dir;
 	FILE *dout = NULL;
 	register char **dirlist, *dirname;
-	char *strpbrk();
 
 	if (strpbrk(whichfiles, "~{[*?") != NULL) {
 		extern char **glob(), *globerr;
