@@ -1,6 +1,9 @@
 /*   change password or add user to S/KEY authentication system.
  *   S/KEY is a tradmark of Bellcore  */
 
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <fcntl.h>
 #include <stdio.h>
 #include <string.h>
 #include <pwd.h>
@@ -36,6 +39,20 @@ char *argv[];
 	char tbuf[27],buf[60];
 	char lastc, me[80];
 	int l;
+	int fd;
+	struct stat st;
+
+	/*
+	 * Make sure that the standard file descriptors are open.
+	 */
+	for (fd = 0; fd < 3; fd++) {
+		if (fstat(fd, &st) == -1
+		    && (close(fd), open("/dev/null", O_RDWR, 0)) != fd) {
+			fprintf(stderr, "/dev/null:");
+			perror("open");
+			exit(1);
+		}
+	}
 
 	time(&now);
 #if 0	/* Choose a more random seed */
